package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcZclb;
import com.ruoyi.tcZz.service.ITcZclbService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 资产列表(tc_zclb)表控制层
 * @author du
 * @since 2024/8/5 13:16
 */
@RestController
@Api(tags = "资产列表")
@RequestMapping("/tcZz/networkSecurity/zclb")
public class TcZclbController extends BaseController {
    @Autowired
    private ITcZclbService tcZclbService;

    /**
     * 查询资产列表列表
     */
    @ApiOperation(value = "查询资产列表列表", response = TcZclb.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZclb tc) {
        startPage();
        List<TcZclb> list = tcZclbService.page(tc);
        return getDataTable(list);
    }

    /**
     * 导出资产列表列表
     */
    @ApiOperation(value = " 导出资产列表列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZclb tc) {
        List<TcZclb> list = tcZclbService.page(tc);
        ExcelUtil<TcZclb> util = new ExcelUtil<>(TcZclb.class);
        util.exportExcel(response, list, "资产列表详情数据");
    }

    /**
     * 获取资产列表信息
     */
    @ApiOperation(value = " 获取资产列表信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZclbService.getById(id));
    }

    /**
     * 新增资产列表
     */
    @ApiOperation(value = "新增资产列表")
    @PostMapping
    public AjaxResult add(@RequestBody TcZclb tc) {
        return toAjax(tcZclbService.insert(tc));
    }

    /**
     * 修改资产列表
     */
    @ApiOperation(value = "修改资产列表")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZclb tc) {
        return toAjax(tcZclbService.update(tc));
    }

    /**
     * 删除资产列表
     */
    @ApiOperation(value = "删除资产列表")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZclbService.deleteByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZclb> util = new ExcelUtil<>(TcZclb.class);
        List<TcZclb> tcZbxqList = util.importExcel(file.getInputStream());
        tcZclbService.importUser(tcZbxqList);
        return AjaxResult.success();
    }


    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) {
        ExcelUtil<TcZclb> util = new ExcelUtil<>(TcZclb.class);
        util.importTemplateExcel(response, "资产列表详情");
    }
    
}
